package webapp_test

import (
	"io"
	"net/http"
	"net/http/httptest"
	"strings"
	"testing"

	"github.com/DATA-DOG/go-sqlmock"
	"gontrol/src/server/webapp"
)

func TestRouter_Homepage(t *testing.T) {
	tmpl, err := webapp.ParseTemplates()
	if err != nil {
		t.Fatalf("parse templates: %v",err)
	}

	appDB, _, err := sqlmock.New()
	if err != nil {
		t.Fatalf("sqlmock: %v", err)
	}
	defer appDB.Close()

	app := &webapp.App{
		Tmpl: tmpl,
		DB: appDB,
	}

	ts := httptest.NewServer(webapp.BuildRouter(app))
	defer ts.Close()

	res, err := http.Get(ts.URL + "/")
	if err != nil {
		t.Fatalf("GET /: %v", err)
	}
	defer res.Body.Close()

	if res.StatusCode != http.StatusOK {
		t.Fatalf("status = %d;  want 200", res.StatusCode)
	}
	body, _ := io.ReadAll(res.Body)
	if !strings.Contains(string(body), "<title>") {
		t.Errorf("homepage HTML missing <title")
	}
}
